ammiBayes.sm.plot: Plot Method for Bayesian Stability Mahalanobis Distance...

View source: R/sm_index.R

ammiBayes.sm.plotR Documentation

Plot Method for Bayesian Stability Mahalanobis Distance (SM_i)

Description

Plot the SM_i Stability Index and Genotype Posterior Mean for the SM_i

Usage

ammiBayes.sm.plot(x, xlab = "Genotype Posterior Mean",
                               ylab = "Bayesian Stability Index (SM_i)",
                               line.col = "darkblue", main = NULL, text.col = "red",
                               pch = 16, cex = 1.5, lwd = 1.5, lty = 2,
                               ylimits = 0.1, grid.col = "gray50"
                              )

Arguments

x

An object of class ammiBayes.sm.

xlab

Character string for the X-axis label. Default is "Genotype Posterior Mean".

ylab

Character string for the Y-axis label. Default is "Bayesian Stability Index (SM_i)".

line.col

Color for the points and error bars. Default is "darkblue".

main

Character string or expression for the plot title. Default is NULL.

text.col

Color for the genotype text labels. Default is "red".

pch

Plotting character symbol. Default is 16

cex

Font size for genotype labels. Default is 1.5

lwd

Numeric value for the thickness of the HPD error bars. Default is 1.5.

lty

Integer or character for the reference grid lines (quadrants). Default is 2 (dashed).

ylimits

Numeric adjustment padding for the Y-axis limits. Default is 0.1.

grid.col

Color for the reference quadrant lines. Default is "gray50".

Author(s)

Luciano A. Oliveira
Carlos P. Silva
Cristian T. E. Mendes
Alessandra Q. Silva
Joel J. Nuvunga
Larissa C. V. Boas
Julio S. S. Bueno-Filho
Diogenes F. Filho
Fabio M. Correa

Examples


library(ammiBayes)
data(ammiData)

Env  <- factor(ammiData$amb)
Rep <- factor(ammiData$rep)
Gen  <- factor(ammiData$gen)
Y  <- ammiData$prod

model <- ammiBayes(Y=Y, Gen=Gen, Env=Env, Rep=Rep, iter=10, 
									 burn=1, jump=2, chains=2)

out <- sm.index(model)


ammiBayes.sm.plot(out)


ammiBayes documentation built on Aug. 24, 2026, 5:14 p.m.