| ammiBayes.sm.plot | R Documentation |
Plot the SM_i Stability Index and Genotype Posterior Mean for the SM_i
ammiBayes.sm.plot(x, xlab = "Genotype Posterior Mean",
ylab = "Bayesian Stability Index (SM_i)",
line.col = "darkblue", main = NULL, text.col = "red",
pch = 16, cex = 1.5, lwd = 1.5, lty = 2,
ylimits = 0.1, grid.col = "gray50"
)
x |
An object of class |
xlab |
Character string for the X-axis label. Default is |
ylab |
Character string for the Y-axis label. Default is |
line.col |
Color for the points and error bars. Default is |
main |
Character string or expression for the plot title. Default is |
text.col |
Color for the genotype text labels. Default is |
pch |
Plotting character symbol. Default is |
cex |
Font size for genotype labels. Default is |
lwd |
Numeric value for the thickness of the HPD error bars. Default is |
lty |
Integer or character for the reference grid lines (quadrants). Default is |
ylimits |
Numeric adjustment padding for the Y-axis limits. Default is |
grid.col |
Color for the reference quadrant lines. Default is |
Luciano A. Oliveira
Carlos P. Silva
Cristian T. E. Mendes
Alessandra Q. Silva
Joel J. Nuvunga
Larissa C. V. Boas
Julio S. S. Bueno-Filho
Diogenes F. Filho
Fabio M. Correa
library(ammiBayes)
data(ammiData)
Env <- factor(ammiData$amb)
Rep <- factor(ammiData$rep)
Gen <- factor(ammiData$gen)
Y <- ammiData$prod
model <- ammiBayes(Y=Y, Gen=Gen, Env=Env, Rep=Rep, iter=10,
burn=1, jump=2, chains=2)
out <- sm.index(model)
ammiBayes.sm.plot(out)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.