| ammiDominance | R Documentation |
Simulated dataset for the AMMI, AMMIGBlup, and AMMIGBlupD models. The object ammiDominance is a list where the first element contains the experiment information and the second object in the list contains the molecular marker information.
data(ammiDominance)
dat.gen is a data frame containing information on 16 genotypes, 6 environments, 30 replicates, and the observed variable Y.
data.marks is a 16 x 1791 matrix, where the rows represent genotypes and the columns represent the molecular markers associated with the genotypes.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.